@@ -17,14 +17,17 @@ LOGGER = getLogger("PyLav.Environment")
 
 def build_from_envvars() -> None:
     from pylav.constants.config.env_var import (
+        DATA_FOLDER,
         DEFAULT_SEARCH_SOURCE,
         EXTERNAL_UNMANAGED_HOST,
+        EXTERNAL_UNMANAGED_NAME,
         EXTERNAL_UNMANAGED_PASSWORD,
         EXTERNAL_UNMANAGED_PORT,
         EXTERNAL_UNMANAGED_SSL,
         FALLBACK_POSTGREST_HOST,
         JAVA_EXECUTABLE,
         LINKED_BOT_IDS,
+        LOCAL_TRACKS_FOLDER,
         MANAGED_NODE_APPLE_MUSIC_API_KEY,
         MANAGED_NODE_APPLE_MUSIC_COUNTRY_CODE,
         MANAGED_NODE_DEEZER_KEY,
@@ -37,6 +40,7 @@ def build_from_envvars() -> None:
         POSTGRES_PORT,
         POSTGRES_SOCKET,
         POSTGRES_USER,
+        PREFER_PARTIAL_TRACKS,
         READ_CACHING_ENABLED,
         REDIS_FULL_ADDRESS_RESPONSE_CACHE,
         TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS,
@@ -61,6 +65,7 @@ def build_from_envvars() -> None:
         "PYLAV__EXTERNAL_UNMANAGED_PORT": EXTERNAL_UNMANAGED_PORT,
         "PYLAV__EXTERNAL_UNMANAGED_PASSWORD": EXTERNAL_UNMANAGED_PASSWORD,
         "PYLAV__EXTERNAL_UNMANAGED_SSL": EXTERNAL_UNMANAGED_SSL,
+        "PYLAV__EXTERNAL_UNMANAGED_NAME": EXTERNAL_UNMANAGED_NAME,
         "PYLAV__TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS": TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS,
         "PYLAV__TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS": TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS,
         "PYLAV__TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS_DAYS": TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS_DAYS,
@@ -73,6 +78,9 @@ def build_from_envvars() -> None:
         "PYLAV__MANAGED_NODE_APPLE_MUSIC_COUNTRY_CODE": MANAGED_NODE_APPLE_MUSIC_COUNTRY_CODE,
         "PYLAV__MANAGED_NODE_YANDEX_MUSIC_ACCESS_TOKEN": MANAGED_NODE_YANDEX_MUSIC_ACCESS_TOKEN,
         "PYLAV__MANAGED_NODE_DEEZER_KEY": MANAGED_NODE_DEEZER_KEY,
+        "PYLAV__PREFER_PARTIAL_TRACKS": PREFER_PARTIAL_TRACKS,
+        "PYLAV__LOCAL_TRACKS_FOLDER": LOCAL_TRACKS_FOLDER,
+        "PYLAV__DATA_FOLDER": DATA_FOLDER,
     }
     with ENV_FILE.open(mode="w") as file:
         LOGGER.debug("Creating %s with the following content: %r", ENV_FILE, data)
